#include <MorseCode.h>

/*
  Arduino Morse Code - Created 2017
    by DonX-Developer

  *** This code was created for an Arduino UNO using the Arduino IDE v1.8.4. ***

  Takes an input of text from the Serial window, converts it into morse code and
  Receives morse code using a key or switch and
  Outputs the morse code to an LED and/or Speaker and the Serial window

  Parts list
  Parts:
    Arduino UNO R3 
		Tested on Genuino 101, Genuino Zero and Mega 2560, 
			however the Genuino boards are 3.3v and the speaker may not sound so loud if at all
    Breadboard
    2 x LEDs different colours or an RGB but only using two colours
    1 or 2 x 330R resistors
    1 x Small Speaker or buzzer
    1 x Morse code key or momentary switch
    Connecting wires

  The Arduino is required to be connected to the computer to enter text and view results in the serial window
  
  When entering text in the serial monitor, this is converted into dits and dahs and is presented in the serial window
    If turned on they are also displayed by the different colour LEDs
    If turned on a sound is played in the speaker

  When using the key or momentary switch for the input:
    A dit or dah is displayed in the serial window
    If turned on they are also displayed by a single LED 
      (this is because there is no way of knowing if it is a dit or dah until the key is raised)
    If turned on a sound is played in the speaker
    
  Arduino pinout
    Pin 11 -    to resistor in series with LED anode and LED cathode to GND
    Pin 12 -    to resistor in series with LED anode and LED cathode to GND
    Pin GND -   ground to LED cathode and speaker (or buzzer)
    Pin 7 -     one side of the key, the other side to GND
    Pin 9 -     to positive lead of speaker
*/




MorseCode morse = MorseCode();//create the Morse object

bool usingSerial = false;//flag for the serial input section

void setup() {
  Serial.begin(9600);//start the serial monitor
  // put your setup code here, to run once:
  morse.led1 = 11;//Arduino pin number of LED1
  morse.led2 = 12;//Arduino pin number of LED2
  morse.morseKey = 7;//Arduino pin number for morse code key (or momentary switch)
  morse.buzzer = 9;//Arduino pin that the buzzer is connected to
  //set up the pins on the Arduino
  pinMode(morse.led1, OUTPUT);
  pinMode(morse.led2, OUTPUT);
  pinMode(morse.buzzer, OUTPUT);
  pinMode(morse.morseKey, INPUT_PULLUP);

  //morse is based on units of time
  //1 unit length = a dit
  //3 units length = a dah
  //1 unit of length between dits and dahs
  //3 units of length between characters of a word
  //7 units of length between words in a sentence
  //you may want to modify the unit length below when learning but 110 seems to be right(ish)
  morse.unit = (110);//the length of a unit, defines the length of dits dahs and spaces etc
  morse.debounceDelay = 80;//the debounce time between key presses, again seems to be right(ish)
  morse.showMorseCharacters = true;//display dit or dah after entry
  morse.showSentence = true;//display the current sentence so far
  morse.showCharacters = true;//display the current character between letters
  morse.showPhrase = true;//display certain built in phrases
  morse.speakerOut = true;//turn speaker on/off
  morse.ledOut = true;//turn leds on/off
  morse.showCharacterGap = true;//helps with the start of the next letter

  morse.resetOutput();//initialise the Morse object
}

void loop() {
  usingSerial = false;
  //get the data from the Serial window to display the character and the morse digits in the serial window
  if (Serial.available() > 0)//loop through the incoming text
  {
    usingSerial = true;
    usingSerial = morse.getMorse(Serial.read());//we have a character, now do stuff with it
  }
  if (!usingSerial)//use the key
  {
    morse.checkKeyPressType();//respond to the keying in of morse code dits and dahs
  }
}
