#include <MorseCode.h>

/*
  Arduino Morse Code From Serial - Created 2017
    by DonX-Developer

  *** This code was created for an Arduino UNO using the Arduino IDE v1.6.9. ***

  Takes an input of text from the Serial window, converts it into morse code
  Outputs the morse code to LEDs and/or Speaker and the Serial window

  Parts list
  Parts:
    Arduino UNO R3 
		Tested on Genuino 101, Genuino Zero and Mega 2560, 
			however the Genuino boards are 3.3v and the speaker may not sound so loud if at all
    Breadboard
    2 x LEDs different colours or an RGB but only using two colours
    1 or 2 x 330R resistors depending on how the LEDs are wired. Only one will be lit at any time.
    1 x Small Speaker or buzzer
    Connecting wires

  The Arduino is required to be connected to the computer to enter text and view results in the serial window
  
  When entering text in the serial monitor, this is converted into dits and dahs and is presented in the serial window
    If turned on they are also displayed by the different colour LEDs
    If turned on a sound is played in the speaker
   
  Arduino pinout
    Pin 11 -    to resistor in series with LED anode and LED cathode to GND
    Pin 12 -    to resistor in series with LED anode and LED cathode to GND
    Pin GND -   ground to LED cathode and speaker (or buzzer)
    Pin 9 -     to positive lead of speaker
*/

MorseCode morse = MorseCode();//create the Morse object

bool usingSerial = false;//flag for the serial input section

void setup() {
  Serial.begin(9600);//start the serial monitor
  morse.led1 = 11;//Arduino pin number of LED1
  morse.led2 = 12;//Arduino pin number of LED2
  morse.buzzer = 9;//Arduino pin that the buzzer is connected to
  //set up the pins on the Arduino
  pinMode(morse.led1, OUTPUT);
  pinMode(morse.led2, OUTPUT);
  pinMode(morse.buzzer, OUTPUT);

  //morse is based on units of time
  //you may want to modify the unit length below when learning but 110 seems to be right(ish)
  morse.unit = (110);//the length of a unit, defines the length of dits dahs and spaces etc
  morse.speakerOut = true;//turn speaker on/off
  morse.ledOut = true;//turn leds on/off

  morse.resetOutput();//initialise the Morse object
}

void loop() {
  usingSerial = false;
  //get the data from the Serial window to display the character and the morse digits in the serial window
  if (Serial.available() > 0)//loop through the incoming text
  {
    usingSerial = true;
    usingSerial = morse.getMorse(Serial.read());//we have a character, now do stuff with it
  }
}
